# coding: utf-8

"""
    Habitat repository and authorization API

    Habitat API  # noqa: E501

    OpenAPI spec version: V1.1.1
    Contact: zives@seas.upenn.edu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from pennprov.models.link_instance import LinkInstance  # noqa: F401,E501
from pennprov.models.rank_instance import RankInstance  # noqa: F401,E501


class SubgraphInstance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ranks': 'list[RankInstance]',
        'links': 'list[LinkInstance]',
        'max_timestamp': 'int'
    }

    attribute_map = {
        'ranks': 'ranks',
        'links': 'links',
        'max_timestamp': 'maxTimestamp'
    }

    def __init__(self, ranks=None, links=None, max_timestamp=None):  # noqa: E501
        """SubgraphInstance - a model defined in Swagger"""  # noqa: E501

        self._ranks = None
        self._links = None
        self._max_timestamp = None
        self.discriminator = None

        if ranks is not None:
            self.ranks = ranks
        if links is not None:
            self.links = links
        if max_timestamp is not None:
            self.max_timestamp = max_timestamp

    @property
    def ranks(self):
        """Gets the ranks of this SubgraphInstance.  # noqa: E501


        :return: The ranks of this SubgraphInstance.  # noqa: E501
        :rtype: list[RankInstance]
        """
        return self._ranks

    @ranks.setter
    def ranks(self, ranks):
        """Sets the ranks of this SubgraphInstance.


        :param ranks: The ranks of this SubgraphInstance.  # noqa: E501
        :type: list[RankInstance]
        """

        self._ranks = ranks

    @property
    def links(self):
        """Gets the links of this SubgraphInstance.  # noqa: E501


        :return: The links of this SubgraphInstance.  # noqa: E501
        :rtype: list[LinkInstance]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this SubgraphInstance.


        :param links: The links of this SubgraphInstance.  # noqa: E501
        :type: list[LinkInstance]
        """

        self._links = links

    @property
    def max_timestamp(self):
        """Gets the max_timestamp of this SubgraphInstance.  # noqa: E501


        :return: The max_timestamp of this SubgraphInstance.  # noqa: E501
        :rtype: int
        """
        return self._max_timestamp

    @max_timestamp.setter
    def max_timestamp(self, max_timestamp):
        """Sets the max_timestamp of this SubgraphInstance.


        :param max_timestamp: The max_timestamp of this SubgraphInstance.  # noqa: E501
        :type: int
        """

        self._max_timestamp = max_timestamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SubgraphInstance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubgraphInstance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
